The helper recognizes both legacy and current output layouts, including
data.ss_new, data_echo.ss_new, data_expval.ss, and data_boot_001.ss.
Usage
get_data_file(dir, file_type = c("all", "input", "expected", "bootstrap"))The helper recognizes both legacy and current output layouts, including
data.ss_new, data_echo.ss_new, data_expval.ss, and data_boot_001.ss.
get_data_file(dir, file_type = c("all", "input", "expected", "bootstrap"))